==> scilab_4.0.orig.tar.gz: scilab-4.0/routines/wsci/Messages.h <==
/* Allan CORNET */
/* INRIA 2005 */

#ifndef _MESSAGESH_
#define _MESSAGESH_

#define MSG_SCIMSG1 "%s -e load(getlongpathname('%s'));disp(getlongpathname('%s')+ascii(32)+'loaded');"
#define MSG_SCIMSG2 "%s -e scicos(getlongpathname('%s'));"
#define MSG_SCIMSG3 "%s -e edit_graph(getlongpathname('%s'));"
#define MSG_SCIMSG4 "%s -e exec(getlongpathname('%s'));"
#define MSG_SCIMSG5 "%s -e scipad(getlongpathname('%s')); "
#define MSG_SCIMSG6 "scipad('%s'); "
#define MSG_SCIMSG7 "Scilab Communication"
#define MSG_SCIMSG8 "%s -e scipad(getlongpathname('%s')); "
#define MSG_SCIMSG9 "LibScilab"
#define MSG_SCIMSG10 "New Scilab"
#define MSG_SCIMSG11 "LIBSCILAB.DLL"
#define MSG_SCIMSG12 "Scilab: Printing"
#define MSG_SCIMSG13 "button"
#define MSG_SCIMSG14 "Zoom"
#define MSG_SCIMSG15 "UnZoom"
#define MSG_SCIMSG16 "2D/3D Rotation"
#define MSG_SCIMSG18 "Scilab is a free copyrighted software.\n\t"
#define MSG_SCIMSG19 "developed by Scilab Group (Inria/Enpc)\n\t"
#define MSG_SCIMSG20 "\n\t email: scilab@inria.fr\n\t"
#define MSG_SCIMSG21 "Scilab"
#define MSG_SCIMSG22 "Scilab pause"
#define MSG_SCIMSG23 "Scilab Graph"

#define MSG_SCIMSG24 "Wscilex <Options> : run Scilab.\n"
#define MSG_SCIMSG24B "scilex <Options> : run Scilab.\n"
#define MSG_SCIMSG25 "-ns:if this option is present the startup file SCI/scilab.star is not executed.\n"
#define MSG_SCIMSG26 "-nb:if this option is present then the scilab welcome banner is not displayed.\n"
#define MSG_SCIMSG27 "-l lang: it fixes the user language.\nThe possible lang values are 'fr' for french and 'eng' for english.\nThe default language is english. This default value is fixed the scilab.star file.\n" 
#define MSG_SCIMSG28 "-f file: Scilab script file is executed first into Scilab.\n" 
#define MSG_SCIMSG29 "-e instruction: Scilab instruction instruction is executed first into Scilab."
#define MSG_SCIMSG30 "Help"
#define MSG_SCIMSG31 "Copyright  "
#define MSG_SCIMSG32 "Ouvrir"
#define MSG_SCIMSG33 "Open"
#define MSG_SCIMSG34 "exec('%s');disp('exec done');"
#define MSG_SCIMSG35 "getf('%s');disp('getf done');"
#define MSG_SCIMSG36 "load('%s');disp('file loaded');"
#define MSG_SCIMSG37 "save('%s');disp('file saved');"
#define MSG_SCIMSG38 "Choisir un rpertoire :"
#define MSG_SCIMSG39 "Choose a Directory :"
#define MSG_SCIMSG40 "Please Select a zone of text"
#define MSG_SCIMSG41 "Veuillez slectionner une zone de texte"
#define MSG_SCIMSG42 "Info."
#define MSG_SCIMSG43 "Clipboard is empty"
#define MSG_SCIMSG44 "Scilab Command Window"
#define MSG_SCIMSG45 "Console Scilab"

#define MSG_SCIMSG46 "%% Usage: -To include a Figure with a caption, insert the TWO following lines\n"
#define MSG_SCIMSG47 "%%        in your Latex file:\n"
#define MSG_SCIMSG48 "%% \\input{This_file_name} \n"
#define MSG_SCIMSG49 "%% \\dessin{The_caption}{The_label}\n"
#define MSG_SCIMSG50 "%%         -To include just a picture, insert the lines \n"
#define MSG_SCIMSG51 "%%         between \\fbox{\\begin{picture}...  and \\end{picture}} below \n"
#define MSG_SCIMSG52 "%%If you prefer cm use the following two lines\n"
#define MSG_SCIMSG53 "OK"
#define MSG_SCIMSG54 "Cancel"
#define MSG_SCIMSG55 "Ready"
#define MSG_SCIMSG56 "&Console"
#define MSG_SCIMSG57 "&About"
#define MSG_SCIMSG58 "Makefile VC "
#define MSG_SCIMSG59 "Makefile ABSOFT "
#define MSG_SCIMSG60 "Debug "
#define MSG_SCIMSG61 "Blend"
#define MSG_SCIMSG62 "Release "
#define MSG_SCIMSG63 "Pentium"
#define MSG_SCIMSG64 "Pentium II and more"
#define MSG_SCIMSG65 "486"
#define MSG_SCIMSG66 "386"
#define MSG_SCIMSG67 "Slection&ner Tout"
#define MSG_SCIMSG68 "Co&pier	Ctrl+C"
#define MSG_SCIMSG69 "C&oller	Ctrl+V"
#define MSG_SCIMSG70 "&Imprimer Selection..."
#define MSG_SCIMSG71 "&Evaluer Selection"
#define MSG_SCIMSG72 "&Ouvrir Selection"
#define MSG_SCIMSG73 "&Aide sur"

#define MSG_SCIMSG74 "Select &All"
#define MSG_SCIMSG75 "&Copy	Ctrl+C"
#define MSG_SCIMSG76 "&Paste	Ctrl+V"
#define MSG_SCIMSG77 "&Print Selection..."
#define MSG_SCIMSG78 "&Evaluate Selection"
#define MSG_SCIMSG79 "&Open Selection"
#define MSG_SCIMSG80 "&Help on"
#define MSG_SCIMSG81 "File %s does not exist.\nDo you want create it ?"
#define MSG_SCIMSG82 "Scilab Editor"
#define MSG_SCIMSG83 "Etes vous sr de quitter ?"
#define MSG_SCIMSG84 "Quitter"

#define MSG_SCIMSG85 "Are you sure to quit ?"
#define MSG_SCIMSG86 "Quit"
#define MSG_SCIMSG87 "Remarque Importante"
#define MSG_SCIMSG88 "Les versions Scilab 4.x seront les dernires  fonctionner avec l'ancien mode graphique.\n\nVeuillez lire le fichier release_notes pour plus de dtails."
#define MSG_SCIMSG89 "Ne plus afficher ce message"
#define MSG_SCIMSG90 "Scilab 4.x versions family will be the last versions working with the old graphics mode.\n\nPlease read the release_notes file for more details."
#define MSG_SCIMSG91 "Don't show this screen at startup"

#define MSG_SCIMSG92 "Black and white"
#define MSG_SCIMSG93 "Color"
#define MSG_SCIMSG94 "Portrait"
#define MSG_SCIMSG95 "Landscape"
#define MSG_SCIMSG96 "Epsf file generation"
#define MSG_SCIMSG97 "end of Epsf generation"
#define MSG_SCIMSG98 "end of Ps file generation"
#define MSG_SCIMSG99 "Epsf and LaTeX files generation"
#define MSG_SCIMSG100 "end of Epsf file and LaTeX file generation"
#define MSG_SCIMSG101 "end of Xfig file generation"
#define MSG_SCIMSG102 "end of GIF file generation"
#define MSG_SCIMSG103 "end of PPM file generation"
#define MSG_SCIMSG104 "end of BMP file generation"

#define MSG_SCIMSG105 "Scilab Document"
#define MSG_SCIMSG106 "Graphical Editor"
#define MSG_SCIMSG107 "Line"
#define MSG_SCIMSG120 "Polyline"
#define MSG_SCIMSG108 "Arrow"
#define MSG_SCIMSG109 "Double Arrow"
#define MSG_SCIMSG110 "Text"
#define MSG_SCIMSG111 "Rectangle"
#define MSG_SCIMSG112 "Circle"
#define MSG_SCIMSG113 "Entity Picker"

#define MSG_SCIMSG114 "Ouvrir release_notes.txt"
#define MSG_SCIMSG115 "Open release_notes.txt"

#define MSG_SCIMSG116 "S&tart entity picker"
#define MSG_SCIMSG117 "St&op entity picker"
#define MSG_SCIMSG118 "&Dmarrer slecteur d'entits"
#define MSG_SCIMSG119 "Arr&ter slecteur d'entits"

#define MSG_SCIMSG121 "Please modify ""ComSpec"" environment variable.\ncommand.com on W9x.\ncmd.exe on W2K and more."

#endif /*_MESSAGESH_*/

==> scilab_4.1.2.orig.tar.gz: scilab-4.1.2/routines/wsci/Messages.h <==
/* Allan CORNET */
/* INRIA 2005 */

#ifndef _MESSAGESH_
#define _MESSAGESH_

#define MSG_SCIMSG1 "%s -e load(getlongpathname('%s'));disp(getlongpathname('%s')+ascii(32)+'loaded');"
#define MSG_SCIMSG2 "%s -e scicos(getlongpathname('%s'));"
#define MSG_SCIMSG3 "%s -e edit_graph(getlongpathname('%s'));"
#define MSG_SCIMSG4 "%s -e exec(getlongpathname('%s'));"
#define MSG_SCIMSG5 "%s -e scipad(getlongpathname('%s')); "
#define MSG_SCIMSG6 "scipad('%s'); "
#define MSG_SCIMSG7 "Scilab Communication"
#define MSG_SCIMSG8 "%s -e scipad(getlongpathname('%s')); "
#define MSG_SCIMSG9 "LibScilab"
#define MSG_SCIMSG10 "New Scilab"
#define MSG_SCIMSG11 "LIBSCILAB.DLL"
#define MSG_SCIMSG12 "Scilab: Printing"
#define MSG_SCIMSG13 "button"
#define MSG_SCIMSG14 "Zoom"
#define MSG_SCIMSG15 "UnZoom"
#define MSG_SCIMSG16 "2D/3D Rotation"
#define MSG_SCIMSG18 "Scilab is a free copyrighted software.\n\t"
#define MSG_SCIMSG19 "developed by Scilab Group (Inria/Enpc)\n\t"
#define MSG_SCIMSG20 "\n\t email: scilab@inria.fr\n\t"
#define MSG_SCIMSG21 "Scilab"
#define MSG_SCIMSG22 "Scilab pause"
#define MSG_SCIMSG23 "Scilab Graph"

#define MSG_SCIMSG24 "Wscilex <Options> : run Scilab.\n"
#define MSG_SCIMSG24B "scilex <Options> : run Scilab.\n"

#define MSG_SCIMSG30 "Help"
#define MSG_SCIMSG31 "Copyright  "
#define MSG_SCIMSG32 "Ouvrir"
#define MSG_SCIMSG33 "Open"
#define MSG_SCIMSG34 "exec('%s');disp('exec done');"
#define MSG_SCIMSG35 "getf('%s');disp('getf done');"
#define MSG_SCIMSG36 "load('%s');disp('file loaded');"
#define MSG_SCIMSG37 "save('%s');disp('file saved');"
#define MSG_SCIMSG38 "Choisir un rpertoire :"
#define MSG_SCIMSG39 "Choose a Directory :"
#define MSG_SCIMSG40 "Please Select a zone of text"
#define MSG_SCIMSG41 "Veuillez slectionner une zone de texte"
#define MSG_SCIMSG42 "Info."
#define MSG_SCIMSG43 "Clipboard is empty"
#define MSG_SCIMSG44 "Scilab Command Window"
#define MSG_SCIMSG45 "Console Scilab"

#define MSG_SCIMSG46 "%% Usage: -To include a Figure with a caption, insert the TWO following lines\n"
#define MSG_SCIMSG47 "%%        in your Latex file:\n"
#define MSG_SCIMSG48 "%% \\input{This_file_name} \n"
#define MSG_SCIMSG49 "%% \\dessin{The_caption}{The_label}\n"
#define MSG_SCIMSG50 "%%         -To include just a picture, insert the lines \n"
#define MSG_SCIMSG51 "%%         between \\fbox{\\begin{picture}...  and \\end{picture}} below \n"
#define MSG_SCIMSG52 "%%If you prefer cm use the following two lines\n"
#define MSG_SCIMSG53 "OK"
#define MSG_SCIMSG54 "Cancel"
#define MSG_SCIMSG55 "Ready"
#define MSG_SCIMSG56 "&Console"
#define MSG_SCIMSG57 "&About"
#define MSG_SCIMSG58 "Makefile VC "
#define MSG_SCIMSG59 "Makefile ABSOFT "
#define MSG_SCIMSG60 "Debug "
#define MSG_SCIMSG61 "Blend"
#define MSG_SCIMSG62 "Release "
#define MSG_SCIMSG63 "Pentium"
#define MSG_SCIMSG64 "Pentium II and more"
#define MSG_SCIMSG65 "486"
#define MSG_SCIMSG66 "386"
#define MSG_SCIMSG67 "Slection&ner Tout"
#define MSG_SCIMSG68 "Co&pier	Ctrl+C"
#define MSG_SCIMSG69 "C&oller	Ctrl+V"
#define MSG_SCIMSG70 "&Imprimer Selection..."
#define MSG_SCIMSG71 "&Evaluer Selection"
#define MSG_SCIMSG72 "&Ouvrir Selection"
#define MSG_SCIMSG73 "&Aide sur"

#define MSG_SCIMSG74 "Select &All"
#define MSG_SCIMSG75 "&Copy	Ctrl+C"
#define MSG_SCIMSG76 "&Paste	Ctrl+V"
#define MSG_SCIMSG77 "&Print Selection..."
#define MSG_SCIMSG78 "&Evaluate Selection"
#define MSG_SCIMSG79 "&Open Selection"
#define MSG_SCIMSG80 "&Help on"
#define MSG_SCIMSG81 "File %s does not exist.\nDo you want create it ?"
#define MSG_SCIMSG82 "Scilab Editor"
#define MSG_SCIMSG83 "Etes vous sr de quitter ?"
#define MSG_SCIMSG84 "Quitter"

#define MSG_SCIMSG85 "Are you sure to quit ?"
#define MSG_SCIMSG86 "Quit"
#define MSG_SCIMSG87 "Remarque Importante"
#define MSG_SCIMSG88 "Les versions Scilab 4.x seront les dernires  fonctionner avec l'ancien mode graphique.\n\nVeuillez lire le fichier release_notes pour plus de dtails."
#define MSG_SCIMSG89 "Ne plus afficher ce message"
#define MSG_SCIMSG90 "Scilab 4.x versions family will be the last versions working with the old graphics mode.\n\nPlease read the release_notes file for more details."
#define MSG_SCIMSG91 "Don't show this screen at startup"

#define MSG_SCIMSG92 "Black and white"
#define MSG_SCIMSG93 "Color"
#define MSG_SCIMSG94 "Portrait"
#define MSG_SCIMSG95 "Landscape"
#define MSG_SCIMSG96 "Epsf file generation"
#define MSG_SCIMSG97 "end of Epsf generation"
#define MSG_SCIMSG98 "end of Ps file generation"
#define MSG_SCIMSG99 "Epsf and LaTeX files generation"
#define MSG_SCIMSG100 "end of Epsf file and LaTeX file generation"
#define MSG_SCIMSG101 "end of Xfig file generation"
#define MSG_SCIMSG102 "end of GIF file generation"
#define MSG_SCIMSG103 "end of PPM file generation"
#define MSG_SCIMSG104 "end of BMP file generation"

#define MSG_SCIMSG105 "Scilab Document"
#define MSG_SCIMSG106 "Graphical Editor"
#define MSG_SCIMSG107 "Line"
#define MSG_SCIMSG120 "Polyline"
#define MSG_SCIMSG108 "Arrow"
#define MSG_SCIMSG109 "Double Arrow"
#define MSG_SCIMSG110 "Text"
#define MSG_SCIMSG111 "Rectangle"
#define MSG_SCIMSG112 "Circle"
#define MSG_SCIMSG113 "Entity Picker"

#define MSG_SCIMSG114 "Ouvrir release_notes.txt"
#define MSG_SCIMSG115 "Open release_notes.txt"

#define MSG_SCIMSG116 "S&tart entity picker"
#define MSG_SCIMSG117 "St&op entity picker"
#define MSG_SCIMSG118 "&Dmarrer slecteur d'entits"
#define MSG_SCIMSG119 "Arr&ter slecteur d'entits"

#define MSG_SCIMSG121 "Please modify ""ComSpec"" environment variable.\ncommand.com on W9x.\ncmd.exe on W2K and more."

#define MSG_SCIMSG122 "Arguments : passes Arguments to Scilab, This Arguments can be retreived\n  by the Scilab function sciargs.\n"
#define MSG_SCIMSG123 "-e Instruction : execute the scilab instruction given in Instruction argument.\n"
#define MSG_SCIMSG124 "-f File : execute the scilab script given in File argument.\n"
#define MSG_SCIMSG125 "  '-e' and '-f' options are mutually exclusive.\n\n"
#define MSG_SCIMSG126 "-l lang : it fixes the user language.\n  The possible lang values are 'fr' for french and 'eng' for english.\n  The default language is english.\n  This default value is fixed the scilab.star file.\n\n" 
#define MSG_SCIMSG127 "-mem N : set the initial stacksize.\n"
#define MSG_SCIMSG128 "-ns : if this option is present the startup file scilab.star is not executed.\n"
#define MSG_SCIMSG129 "-nb : if this option is present then scilab welcome banner is not displayed.\n"
#define MSG_SCIMSG130 "-nouserstartup : don't execute user startup files SCIHOME/.scilab or SCIHOME/scilab.ini.\n"
#define MSG_SCIMSG131 "-nw : start Scilab without specialized Scilab Window.\n"
#define MSG_SCIMSG132 "-nwni : start Scilab without user interaction (batch mode).\n"
#define MSG_SCIMSG133 "-nogui : start Scilab without GUI,tcl/tk and user interaction (batch mode).\n"
#define MSG_SCIMSG134 "-texmacs : reserved for WinTeXMacs.\n"



#endif /*_MESSAGESH_*/
